==> mingw-w64-clang-i686-gammaray-qt5-2.11.3-3-any.pkg.tar.zst: clang32/lib/cmake/GammaRay/GammaRayTarget-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "gammaray_kitemmodels" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_kitemmodels APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_kitemmodels PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_kitemmodels-qt5_15-Clang-i686.dll.a"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_kitemmodels-qt5_15-Clang-i686.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gammaray_kitemmodels )
list(APPEND _IMPORT_CHECK_FILES_FOR_gammaray_kitemmodels "${_IMPORT_PREFIX}/lib/libgammaray_kitemmodels-qt5_15-Clang-i686.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_kitemmodels-qt5_15-Clang-i686.dll" )

# Import target "gammaray_common" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_common APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_common PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_common-qt5_15-Clang-i686.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Qt5::Network;Qt5::Gui;gammaray_kitemmodels"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_common-qt5_15-Clang-i686.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gammaray_common )
list(APPEND _IMPORT_CHECK_FILES_FOR_gammaray_common "${_IMPORT_PREFIX}/lib/libgammaray_common-qt5_15-Clang-i686.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_common-qt5_15-Clang-i686.dll" )

# Import target "gammaray_core" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_core PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_core-qt5_15-Clang-i686.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "gammaray_kitemmodels;Qt5::Gui"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_core-qt5_15-Clang-i686.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gammaray_core )
list(APPEND _IMPORT_CHECK_FILES_FOR_gammaray_core "${_IMPORT_PREFIX}/lib/libgammaray_core-qt5_15-Clang-i686.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_core-qt5_15-Clang-i686.dll" )

# Import target "gammaray_probe" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_probe APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_probe PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_probe-qt5_15-Clang-i686.dll.a"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_probe-qt5_15-Clang-i686.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gammaray_probe )
list(APPEND _IMPORT_CHECK_FILES_FOR_gammaray_probe "${_IMPORT_PREFIX}/lib/libgammaray_probe-qt5_15-Clang-i686.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_probe-qt5_15-Clang-i686.dll" )

# Import target "gammaray_launcher" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_launcher APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_launcher PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_launcher.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "gammaray_common;Qt5::Network;Qt5::Gui;Qt5::Widgets"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_launcher.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gammaray_launcher )
list(APPEND _IMPORT_CHECK_FILES_FOR_gammaray_launcher "${_IMPORT_PREFIX}/lib/libgammaray_launcher.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_launcher.dll" )

# Import target "gammaray_launcher_ui" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_launcher_ui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_launcher_ui PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_launcher_ui.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Qt5::Core;Qt5::Concurrent;Qt5::Gui;Qt5::Widgets;Qt5::Network;gammaray_ui"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_launcher_ui.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gammaray_launcher_ui )
list(APPEND _IMPORT_CHECK_FILES_FOR_gammaray_launcher_ui "${_IMPORT_PREFIX}/lib/libgammaray_launcher_ui.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_launcher_ui.dll" )

# Import target "gammaray_kuserfeedback" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_kuserfeedback APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_kuserfeedback PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_kuserfeedback.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Qt5::Gui;Qt5::Network"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_kuserfeedback.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gammaray_kuserfeedback )
list(APPEND _IMPORT_CHECK_FILES_FOR_gammaray_kuserfeedback "${_IMPORT_PREFIX}/lib/libgammaray_kuserfeedback.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_kuserfeedback.dll" )

# Import target "gammaray_ui" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_ui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_ui PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_ui-qt5_15-Clang-i686.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "gammaray_kitemmodels;KF5::SyntaxHighlighting"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_ui-qt5_15-Clang-i686.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gammaray_ui )
list(APPEND _IMPORT_CHECK_FILES_FOR_gammaray_ui "${_IMPORT_PREFIX}/lib/libgammaray_ui-qt5_15-Clang-i686.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_ui-qt5_15-Clang-i686.dll" )

# Import target "gammaray_client" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_client APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_client PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_client.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "gammaray_ui;gammaray_common;Qt5::Gui;Qt5::Widgets;Qt5::Network"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_client.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS gammaray_client )
list(APPEND _IMPORT_CHECK_FILES_FOR_gammaray_client "${_IMPORT_PREFIX}/lib/libgammaray_client.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_client.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-i686-gammaray-qt5-2.11.3-4-any.pkg.tar.zst: clang32/lib/cmake/GammaRay/GammaRayTarget-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "gammaray_kitemmodels" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_kitemmodels APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_kitemmodels PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_kitemmodels-qt5_15-Clang-i686.dll.a"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_kitemmodels-qt5_15-Clang-i686.dll"
  )

list(APPEND _cmake_import_check_targets gammaray_kitemmodels )
list(APPEND _cmake_import_check_files_for_gammaray_kitemmodels "${_IMPORT_PREFIX}/lib/libgammaray_kitemmodels-qt5_15-Clang-i686.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_kitemmodels-qt5_15-Clang-i686.dll" )

# Import target "gammaray_common" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_common APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_common PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_common-qt5_15-Clang-i686.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Qt5::Network;Qt5::Gui;gammaray_kitemmodels"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_common-qt5_15-Clang-i686.dll"
  )

list(APPEND _cmake_import_check_targets gammaray_common )
list(APPEND _cmake_import_check_files_for_gammaray_common "${_IMPORT_PREFIX}/lib/libgammaray_common-qt5_15-Clang-i686.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_common-qt5_15-Clang-i686.dll" )

# Import target "gammaray_core" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_core PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_core-qt5_15-Clang-i686.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "gammaray_kitemmodels;Qt5::Gui"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_core-qt5_15-Clang-i686.dll"
  )

list(APPEND _cmake_import_check_targets gammaray_core )
list(APPEND _cmake_import_check_files_for_gammaray_core "${_IMPORT_PREFIX}/lib/libgammaray_core-qt5_15-Clang-i686.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_core-qt5_15-Clang-i686.dll" )

# Import target "gammaray_probe" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_probe APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_probe PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_probe-qt5_15-Clang-i686.dll.a"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_probe-qt5_15-Clang-i686.dll"
  )

list(APPEND _cmake_import_check_targets gammaray_probe )
list(APPEND _cmake_import_check_files_for_gammaray_probe "${_IMPORT_PREFIX}/lib/libgammaray_probe-qt5_15-Clang-i686.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_probe-qt5_15-Clang-i686.dll" )

# Import target "gammaray_launcher" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_launcher APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_launcher PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_launcher.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "gammaray_common;Qt5::Network;Qt5::Gui;Qt5::Widgets"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_launcher.dll"
  )

list(APPEND _cmake_import_check_targets gammaray_launcher )
list(APPEND _cmake_import_check_files_for_gammaray_launcher "${_IMPORT_PREFIX}/lib/libgammaray_launcher.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_launcher.dll" )

# Import target "gammaray_launcher_ui" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_launcher_ui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_launcher_ui PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_launcher_ui.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Qt5::Core;Qt5::Concurrent;Qt5::Gui;Qt5::Widgets;Qt5::Network;gammaray_ui"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_launcher_ui.dll"
  )

list(APPEND _cmake_import_check_targets gammaray_launcher_ui )
list(APPEND _cmake_import_check_files_for_gammaray_launcher_ui "${_IMPORT_PREFIX}/lib/libgammaray_launcher_ui.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_launcher_ui.dll" )

# Import target "gammaray_kuserfeedback" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_kuserfeedback APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_kuserfeedback PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_kuserfeedback.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Qt5::Gui;Qt5::Network"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_kuserfeedback.dll"
  )

list(APPEND _cmake_import_check_targets gammaray_kuserfeedback )
list(APPEND _cmake_import_check_files_for_gammaray_kuserfeedback "${_IMPORT_PREFIX}/lib/libgammaray_kuserfeedback.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_kuserfeedback.dll" )

# Import target "gammaray_ui" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_ui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_ui PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_ui-qt5_15-Clang-i686.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "gammaray_kitemmodels;KF5::SyntaxHighlighting"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_ui-qt5_15-Clang-i686.dll"
  )

list(APPEND _cmake_import_check_targets gammaray_ui )
list(APPEND _cmake_import_check_files_for_gammaray_ui "${_IMPORT_PREFIX}/lib/libgammaray_ui-qt5_15-Clang-i686.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_ui-qt5_15-Clang-i686.dll" )

# Import target "gammaray_client" for configuration "RelWithDebInfo"
set_property(TARGET gammaray_client APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(gammaray_client PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libgammaray_client.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "gammaray_ui;gammaray_common;Qt5::Gui;Qt5::Widgets;Qt5::Network"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/libgammaray_client.dll"
  )

list(APPEND _cmake_import_check_targets gammaray_client )
list(APPEND _cmake_import_check_files_for_gammaray_client "${_IMPORT_PREFIX}/lib/libgammaray_client.dll.a" "${_IMPORT_PREFIX}/bin/libgammaray_client.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
